@@ -54,6 +54,9 @@ fn parse_markdown(input: &str) -> ParseResult<Markdown> {
 fn parse_block(input: &str) -> ParseResult<Block> {
     let parse_hr = map(preceded(tag("---"), line_ending), |_| Block::HorizontalRule);
 
+    let parse_pagetitle = map(preceded(pair(tag("%"), space0), parse_text_line), |text| {
+        Block::Heading(1, text)
+    });
     let parse_heading = map(
         tuple((take_while_m_n(1, 6, |c| c == '#'), space1, parse_text_line)),
         |(hashes, _, text)| Block::Heading(hashes.len(), text),
@@ -119,8 +122,14 @@ fn parse_block(input: &str) -> ParseResult<Block> {
         },
     );
 
+    let parse_mathjax = map(
+        terminated(delimited(tag("$$"), parse_tex, tag("$$")), line_ending),
+        |tex| Block::MathJax(tex.to_string()),
+    );
+
     alt((
         parse_hr,
+        parse_pagetitle,
         parse_heading,
         parse_code,
         parse_listblock,
@@ -129,6 +138,7 @@ fn parse_block(input: &str) -> ParseResult<Block> {
         parse_import,
         parse_code_import,
         parse_hyperlink,
+        parse_mathjax,
         parse_paragraph,
     ))(input)
 }
@@ -182,14 +192,17 @@ fn parse_table(input: &str) -> ParseResult<Block> {
 /// Parse text without newline
 fn parse_text(input: &str) -> ParseResult<Text> {
     let parse_emphasis_and_strong = map(
-        map_parser(delimited(tag("***"), is_not("***"), tag("***")), parse_text),
+        map_parser(
+            delimited(tag("***"), take_until("***"), tag("***")),
+            parse_text,
+        ),
         Inline::EmphasisAndStrong,
     );
     let parse_strong = map(
         map_parser(
             alt((
-                delimited(tag("**"), is_not("**"), tag("**")),
-                delimited(tag("__"), is_not("__"), tag("__")),
+                delimited(tag("**"), take_until("**"), tag("**")),
+                delimited(tag("__"), take_until("__"), tag("__")),
             )),
             parse_text,
         ),
@@ -198,7 +211,7 @@ fn parse_text(input: &str) -> ParseResult<Text> {
     let parse_emphasis = map(
         map_parser(
             alt((
-                delimited(tag("*"), is_not("*"), tag("*")),
+                delimited(tag("*"), take_until("*"), tag("*")),
                 delimited(tag("_"), is_not("_"), tag("_")),
             )),
             parse_text,
@@ -206,7 +219,10 @@ fn parse_text(input: &str) -> ParseResult<Text> {
         Inline::Emphasis,
     );
     let parse_deleted = map(
-        map_parser(delimited(tag("~~"), is_not("~~"), tag("~~")), parse_text),
+        map_parser(
+            delimited(tag("~~"), take_until("~~"), tag("~~")),
+            parse_text,
+        ),
         Inline::Deleted,
     );
     let parse_code = map(delimited(tag("`"), is_not("`"), tag("`")), |text: &str| {
@@ -229,13 +245,16 @@ fn parse_text(input: &str) -> ParseResult<Text> {
         |(text, url): (Text, &str)| Inline::Link(text, url.to_string()),
     );
     let parse_hyperlink = map(
-        delimited(tag("[["), is_not("]]"), tag("]]")),
+        delimited(tag("[["), take_until("]]"), tag("]]")),
         |url: &str| Inline::HyperLink(url.to_string()),
     );
     let parse_comment = map(
-        delimited(tag("<!--"), is_not("-->"), tag("-->")),
+        delimited(tag("<!--"), take_until("-->"), tag("-->")),
         |text: &str| Inline::Comment(text.to_string()),
     );
+    let parse_mathjax = map(delimited(tag("$"), parse_tex, tag("$")), |tex| {
+        Inline::MathJax(tex)
+    });
 
     many1(preceded(
         space0,
@@ -249,6 +268,7 @@ fn parse_text(input: &str) -> ParseResult<Text> {
             parse_deleted,
             parse_code,
             parse_comment,
+            parse_mathjax,
             parse_plaintext,
         )),
     ))(input)
@@ -269,33 +289,35 @@ fn parse_plaintext(input: &str) -> ParseResult<Inline> {
     let safe_one_char = preceded(
         not(alt((
             tag(" "),
-            tag("*"),
-            tag("`"),
-            tag("~~"),
-            tag("["),
-            tag("]"),
             tag("!["),
-            tag("|"),
+            tag("$"),
+            tag("*"),
+            tag("<!--"),
+            tag("["),
             tag("\\"),
             tag("\n"),
             tag("\r"),
-            tag("<!--"),
+            tag("]"),
+            tag("`"),
+            tag("|"),
+            tag("~~"),
         ))),
         take(1u8),
     );
     let escaped_char = map(
         alt((
-            tag("\\`"),
-            tag("\\~"),
-            tag("\\<"),
-            tag("\\>"),
-            tag("\\|"),
             tag("\\ "),
             tag("\\!"),
-            tag("\\["),
-            tag("\\]"),
+            tag("\\$"),
             tag("\\*"),
+            tag("\\<"),
+            tag("\\>"),
+            tag("\\["),
             tag("\\\\"),
+            tag("\\]"),
+            tag("\\`"),
+            tag("\\|"),
+            tag("\\~"),
         )),
         |e: &str| &e[1..2],
     );
@@ -366,6 +388,12 @@ fn parse_list<'r>(indent: usize) -> impl FnMut(&'r str) -> ParseResult<'r, List>
     })
 }
 
+/// Inner of $...$, $$...$$
+fn parse_tex(input: &str) -> ParseResult<String> {
+    let safe_one_char = preceded(not(alt((tag("$"), tag("\\$")))), take(1u8));
+    map(many1(alt((safe_one_char, tag("\\$")))), |v| v.join(""))(input)
+}
+
 #[cfg(test)]
 mod test_parser {
 
@@ -519,6 +547,12 @@ mod test_parser {
                 Inline::HyperLink(String::from("hyperlink")),
             }]
         );
+        assert_parse!(
+            "***x~y***\n",
+            vec![p! {
+                Inline::EmphasisAndStrong(vec![text!("x~y")]),
+            }]
+        );
         assert_parse!(
             "Hello *world* **!** \\*\\!\n\n",
             vec![p! {
@@ -546,6 +580,14 @@ mod test_parser {
             "~~Hello~~\n",
             vec![p! { Inline::Deleted(vec![text!("Hello")]) }]
         );
+        assert_parse!(
+            "~~x~y~~\n",
+            vec![p! { Inline::Deleted(vec![text!("x~y")]) }]
+        );
+        assert_parse!(
+            "~~*z*~~\n",
+            vec![p! { Inline::Deleted(vec![Inline::Emphasis(vec![text!("z")])]) }]
+        );
         assert_parse!("~Hello~\n", vec![p! { text!("~Hello~") }]);
         assert_parse!("~Hello\n", vec![p! { text!("~Hello") }]);
     }
@@ -863,6 +905,12 @@ fn main(){{}}```
                 text!("."),
             }]
         );
+        assert_parse!(
+            "<!-- x-y -> -->\n",
+            vec![p! {
+                comment!(" x-y -> "),
+            }]
+        );
     }
 
     #[test]
@@ -932,4 +980,29 @@ fn main(){{}}```
             vec![Block::CodeImport(None, String::from("main.rs"))]
         );
     }
+
+    #[test]
+    fn test_mathjax() {
+        assert_parse!(
+            "$$f(x) = x^2.$$\n",
+            vec![Block::MathJax(String::from("f(x) = x^2."))]
+        );
+        assert_parse!(
+            "$f(x) = x^2$\n",
+            vec![p! {Inline::MathJax(String::from("f(x) = x^2"))}]
+        );
+        assert_parse!(
+            "From $f(x) = x^2$.\n",
+            vec![p! {
+                text!("From"),
+                Inline::MathJax(String::from("f(x) = x^2")),
+                text!(".")
+            }]
+        );
+        assert_parse!("$$\\$$$\n", vec![Block::MathJax(String::from("\\$"))]);
+        assert_parse!(
+            "$\\mu\\$$\n",
+            vec![p! {Inline::MathJax(String::from("\\mu\\$"))}]
+        );
+    }
 }
